FlexiAspect enum

Aspects that can be used to listen for specific changes in Flexi UI.

Using these aspects allows widgets to rebuild only when the relevant piece of responsive data changes, improving performance by avoiding unnecessary rebuilds.

Inheritance
Available extensions

Values

width → const FlexiAspect

Listen for changes to the screen width.

height → const FlexiAspect

Listen for changes to the screen height.

pixelRatio → const FlexiAspect

Listen for changes to the device pixel ratio.

breakpoint → const FlexiAspect

Listen for changes to the semantic breakpoint.

implicit → const FlexiAspect

Internal aspect used when no explicit aspect is provided. Used to manage strict mode rebuilds.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FlexiAspect>
A constant List of the values in this enum, in order of their declaration.