FlexiLayout class
A widget that switches its content based on the current breakpoint.
FlexiLayout allows you to provide different widget trees for mobile, tablet, and desktop breakpoints. It uses Flexi.of(context) to listen specifically to breakpoint changes (aspect: FlexiAspect.breakpoint), ensuring efficient rebuilds.
If a specific layout is not provided, it falls back gracefully:
- Desktop falls back to Tablet, then Mobile.
- Tablet falls back to Mobile.
- Mobile is required (or inferred if others are missing, but practically required).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FlexiLayout
Constructors
- FlexiLayout({Key? key, required Widget mobile, Widget? tablet, Widget? desktop})
-
const
Properties
- desktop → Widget?
-
The widget to display on desktop devices.
If null, tablet (if available) or mobile will be used.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mobile → Widget
-
The widget to display on mobile devices (phone portrait/landscape).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tablet → Widget?
-
The widget to display on tablet devices (landscape).
If null, mobile will be used.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited